Crate tql [−] [src]
TQL is a Rust compiler plugin providing an SQL DSL.
It type check your expression at compile time and converts it to SQL.
Modules
| aggregates |
Macros
| check_missing_fields | |
| sql |
Traits
| ToTqlType |
Type Definitions
| ForeignKey |
The |
| PrimaryKey |
A |